#ifndef LIGHTCURVE_H_
#define LIGHTCURVE_H_

#include <string>
#include <vector>
#include <map>

#include <Dal.h>
#include <DataSubspace.h>
#include "LCGrid.h"
#include "Spect.h"

class LightCurve {

public:
	LightCurve(){};
	LightCurve(string timeSerie, string evtList);
	LightCurve(string bkgSerie);
	LightCurve(double val0, double val1, double binSize=1.0);
	~LightCurve();

	void doRelativeCorr();
	void calSpec();
	Spect* getSpec();

	void doAbsoluteCorr();
	void applyAbsCorr();
	LCGrid* getLC();

	void createFile(string outFileName);

	std::string _instrument;

	LightCurve* operator-(LightCurve* bkg);

private:
	LCGrid* setLC(string timeSerie);
	void setDSS();
	void setEventList(string evtList);
	void createCCDsLC();
	void setCCDsInRegion();
	void doGTICorr(LCGrid* lc);
	void doExposureCorr(LCGrid* lc);
	void closeTimeSerie();
	void closeEventList();

	std::vector<std::string> searchFor(LCGrid *lc);


	LCGrid *_LC;
	Spect *_spec;
	std::string _evtListName;
	DataSet *_evtList;
	DataSet *_ts;
	std::vector<LCGrid*> _ccdLC;
	std::vector<int> _ccdInRegion;
	DataSubspace _dss;
	bool _tsExists;
	bool _evtExists;
	bool _bkgCorrected;
	std::string _telescope;
	std::string _filter;
	double _mjdref;
	std::string _timeSys;
	std::string _timeSysComment;
	std::string _timeUnit;
	std::string _timeRef;
	std::string _timeRefComment;
	std::string _timeAssign;
	std::string _timeAssignComment;
	std::string _timeClockApp;
	std::string _subMode;

};




#endif /*LIGHTCURVE_H_*/
